@@ -1,4 +1,4 @@
-/* $Id: bibli1.c,v 1.60.2.3 2002/03/12 19:31:14 cvsadmin Exp $
+/* $Id: bibli1.c,v 1.60.2.4 2003/01/27 17:56:01 bill Exp $
 
 Copyright (C) 2000  The PARI group.
 
@@ -2200,7 +2200,8 @@ chk_gen_init(FP_chk_fun *chk, GEN nf, GEN gram, GEN mat, long *ptprec)
         if (prev && !gegal(prev,P))
         {
           if (degree(prev) * degree(P) > 32) continue; /* too expensive */
-          P = (GEN)compositum(prev,P)[1];
+          P = compositum(prev,P);
+          P = (GEN)P[lg(P)-1];
           if (lgef(P)-3 == n) continue;
           if (DEBUGLEVEL>2 && lgef(P)>lgef(prev))
             fprintferr("chk_gen_init: subfield %Z\n",P);
